@@ -8,9 +8,9 @@
 setMethod(f = 'print',
           signature(x = 'rnetBasic'),
           function(x) {
-            cat(  '\nVertex set:',	paste(x@V_set, collapse = ' '),
+            cat(  '\nVertex set:',	paste(x@vertices, collapse = ' '),
                   '\n',
-                  '\n  Edge Set:',
+                  '\n  Edge set:',
                   '\n')
             edge.frame <- data.frame(V1 = as_edgelist(x@R)[,1],
                                      V2 = as_edgelist(x@R)[,2],
@@ -22,20 +22,29 @@ setMethod(f = 'print',
 #' @rdname print
 #' 
 setMethod(f = 'print',
-          signature(x = 'rnetStrata'),
+          signature(x = 'rnetSubset'),
           function(x) {
-            cat(	'\nRnet conditioned on', as.character(x@Strata_def), '\n')
+            cat(	'\nRnet conditioned on', as.character(x@subset), '\n')
             print(as(x, 'rnetBasic'))
           })
 
 #' @rdname print
 #' 
 setMethod(f = 'print',
-          signature(x = 'rnetMultiStrata'),
+          signature(x = 'rnetStrata'),
           function(x) {
-            cat(	"\nRnet stratified by ", x@Stratify_by, " (", length(x@R_Strata), " Strata)\n", sep = '')
-            cat(  '\nVertex set:',	paste(unique(unlist(lapply(x@R_Strata, function(x) x@V_set ))), collapse = ' '), "\n")
+            cat(	"\nRnet stratified by ", x@stratify_by, " (", length(x@R_set), " Strata)\n", sep = '')
+            cat(  '\nVertex set:',	paste(unique(unlist(lapply(x@R_set, function(x) x@vertices ))), collapse = ' '), "\n")
             cat(  '\nEdge set:\n')
-            print(.Assemble_Edge_Matrix(x, 'omega'))
+            print(.Aggregate_Edges(x, 'omega'))
             
           })
+#' @rdname print
+#' 
+setMethod(f = 'print',
+          signature(x = 'rnet.L1.set'),
+          function(x) {
+            cat('\nStability Approach for Regularization Selection (StARS) results\n\nD_b by L1\n')
+            output <- round(x@D, 4)
+            print(output)
+          })
